@@ -7,7 +7,7 @@ def print_line(line):
     """
     Print given line to stdout (i3bar).
     """
-    sys.__stdout__.write('{}\n'.format(line))
+    sys.__stdout__.write("{}\n".format(line))
     sys.__stdout__.flush()
 
 
