@@ -26,6 +26,7 @@ class MockPy3statusWrapper:
             "minimum_interval": 0.1,
             "testing": True,
             "log_file": True,
+            "wm": {"msg": "i3-msg", "nag": "i3-nagbar"},
         }
         self.events_thread = self.EventThread()
         self.udev_monitor = self.UdevMonitor()
@@ -90,7 +91,7 @@ def module_test(module_class, config=None):
                     del item["name"]
 
             if "--term" in argv:
-                line = ""
+                line = "\033[0m"
                 for item in output:
                     if item.get("urgent"):
                         line += "\033[41m"
