@@ -16,7 +16,7 @@ Configuration parameters:
     unit: specify the systemd unit to use (default 'dbus.service')
     user: specify if this is a user service (default False)
 
-Format of status string placeholders:
+Format placeholders:
     {unit} unit name, eg sshd.service
     {status} unit status, eg active, inactive, not-found
 
@@ -25,6 +25,9 @@ Color options:
     color_bad: unit inactive
     color_degraded: unit not-found
 
+Requires:
+    pydbus: pythonic dbus library
+
 Examples:
 ```
 # show the status of vpn service
@@ -36,9 +39,6 @@ systemd vpn {
 }
 ```
 
-Requires:
-    pydbus: pythonic dbus library
-
 @author Adrian Lopez <adrianlzt@gmail.com>
 @license BSD
 
