@@ -237,23 +237,23 @@ Examples:
 ```
 # change icons
 weather_owm {
-  api_key = <my api key>
-  icons = {
-    '200': "☔"
-    '230_232': "🌧"
-  }
+    api_key = <my api key>
+    icons = {
+        '200': "☔"
+        '230_232': "🌧"
+    }
 }
 
 # set a city
 weather_owm {
-  api_key = <my api key>
-  city = 'London'
+    api_key = <my api key>
+    city = 'London'
 }
 
 # set a location
 weather_owm {
-  api_key = <my api key>
-  location = (2.3548, 48.9342)  # Saint-Denis
+    api_key = <my api key>
+    location = (48.9342, 2.3548)  # Saint-Denis
 }
 ```
 
@@ -313,14 +313,11 @@ THRESHOLDS_NAMES = set([THRESHOLDS_ALL, "current", "min", "max"])
 THRESHOLDS = {"all": [(-100, "#0FF"), (0, "#00F"), (50, "#0F0"), (150, "#FF0")]}
 
 
-class OWMException(Exception):
-    pass
-
-
 class Py3status:
     """
     """
 
+    # available configuration parameters
     api_key = None
     cache_timeout = 600
     city = None
@@ -404,7 +401,7 @@ class Py3status:
     def post_config_hook(self):
         # Verify the API key
         if self.api_key is None:
-            raise OWMException(
+            raise Exception(
                 "API Key for OpenWeatherMap cannot be empty!"
                 " Go to https://openweathermap.org/appid to"
                 " get an API Key."
@@ -438,9 +435,11 @@ class Py3status:
         req = self.py3.request(url, params=params)
         if req.status_code != 200:
             data = req.json()
-            raise OWMException(
-                data["message"] if (data and "message" in data) else "API Error"
-            )
+            if data and "message" in data:
+                msg = data["message"]
+            else:
+                msg = "{_error_message} {_status_code}".format(**vars(req))
+            self.py3.error(msg)
 
         return req.json()
 
@@ -772,7 +771,7 @@ class Py3status:
         if loc_tz_info is not None:
             (coords, city, country, tz_offset) = loc_tz_info
             if coords:
-                extras = {"lon": coords[0], "lat": coords[1]}
+                extras = {"lat": coords[0], "lon": coords[1]}
             elif city:
                 extras = {"q": city}
             wthr = self._get_weather(extras)
